/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.uniffle.common;

public class ShuffleIndexResult {
  private final byte[] indexData;
  private long dataFileLen;

  public ShuffleIndexResult() {
    this(new byte[0], -1);
  }

  public ShuffleIndexResult(byte[] bytes, long dataFileLen) {
    this.indexData = bytes;
    this.dataFileLen = dataFileLen;
  }

  public byte[] getIndexData() {
    return indexData;
  }

  public long getDataFileLen() {
    return dataFileLen;
  }

  public boolean isEmpty() {
    return indexData == null || indexData.length == 0;
  }
}
